Struct sosecrets_rs::types::NumericalZeroSizedType
source · pub struct NumericalZeroSizedType {}Trait Implementations
sourceimpl Add for NumericalZeroSizedType
impl Add for NumericalZeroSizedType
sourceimpl AddAssign for NumericalZeroSizedType
impl AddAssign for NumericalZeroSizedType
sourcefn add_assign(&mut self, _other: Self)
fn add_assign(&mut self, _other: Self)
Performs the
+= operation. Read moresourceimpl ChooseMinimallyRepresentableUInt for NumericalZeroSizedType
impl ChooseMinimallyRepresentableUInt for NumericalZeroSizedType
type Output = NumericalZeroSizedType
type Output = NumericalZeroSizedType
The Rust’s primitive unsigned integer type that is minimally representable of the unsigned integer represented at the type level by
Self.
e.g. If Self is typenum::consts::U69, then Self::Output is u8.type AtomicOutput = NumericalZeroSizedType
type AtomicOutput = NumericalZeroSizedType
Currently, a placeholder for future feature of this crate. Safe to put a placeholder here because this is a ‘Sealed’ trait.
sourceconst ZERO: Self::Output = _
const ZERO: Self::Output = _
The additive identity of the type
Self::Output, e.g. 0_usize, 0_u32.sourceconst ONE: Self::Output = _
const ONE: Self::Output = _
The multiplicative identity of the type
Self::Output, e.g. 1_usize, 1_u32.sourcefn cast_unsigned_to_self_type<T: Unsigned>(_: SealedToken) -> Self::Output
fn cast_unsigned_to_self_type<T: Unsigned>(_: SealedToken) -> Self::Output
A convenient method to convert the unsigned integer represented at the type level by
Self to a value of type Self::Output.
e.g. converting from typenum::consts::U69 to 69_u8.sourceimpl Clone for NumericalZeroSizedType
impl Clone for NumericalZeroSizedType
sourcefn clone(&self) -> NumericalZeroSizedType
fn clone(&self) -> NumericalZeroSizedType
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for NumericalZeroSizedType
impl Debug for NumericalZeroSizedType
sourceimpl Default for NumericalZeroSizedType
impl Default for NumericalZeroSizedType
sourcefn default() -> NumericalZeroSizedType
fn default() -> NumericalZeroSizedType
Returns the “default value” for a type. Read more
sourceimpl Display for NumericalZeroSizedType
impl Display for NumericalZeroSizedType
sourceimpl Hash for NumericalZeroSizedType
impl Hash for NumericalZeroSizedType
sourceimpl Ord for NumericalZeroSizedType
impl Ord for NumericalZeroSizedType
sourcefn cmp(&self, other: &NumericalZeroSizedType) -> Ordering
fn cmp(&self, other: &NumericalZeroSizedType) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for NumericalZeroSizedType
impl PartialEq for NumericalZeroSizedType
sourcefn eq(&self, other: &NumericalZeroSizedType) -> bool
fn eq(&self, other: &NumericalZeroSizedType) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for NumericalZeroSizedType
impl PartialOrd for NumericalZeroSizedType
sourcefn partial_cmp(&self, other: &NumericalZeroSizedType) -> Option<Ordering>
fn partial_cmp(&self, other: &NumericalZeroSizedType) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for NumericalZeroSizedType
impl Eq for NumericalZeroSizedType
impl StructuralPartialEq for NumericalZeroSizedType